/*****************************************************************************
*
* @brief Linker script.
*
* @author evgeny.linsky@cloudbear.ru, vitaly.gaiduk@cloudbear.ru
*
* Copyright (c) 2018 CloudBEAR LLC - http://www.cloudbear.ru/
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions
* are met:
*
*   Redistributions of source code must retain the above copyright
*   notice, this list of conditions and the following disclaimer.
*
*   Redistributions in binary form must reproduce the above copyright
*   notice, this list of conditions and the following disclaimer in the
*   documentation and/or other materials provided with the
*   distribution.
*
*   Neither the name of CloudBEAR nor the names of
*   its contributors may be used to endorse or promote products derived
*   from this software without specific prior written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
* "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
* LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
* A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
* OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
* SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
* LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
* DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
* THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
* OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*
******************************************************************************/

OUTPUT_ARCH( "riscv" )
ENTRY(_start)

__vma_text_start = 0x00020000;

TCM_START_ADDR = 0xffffffff80010000;
TCM_END_ADDR = 0x80018000;
__vma_data_start = TCM_START_ADDR;
__vma_data_start_32 = __vma_data_start & 0xffffffff;

SECTIONS
{
  . = __vma_text_start;
  .text __vma_text_start : AT(__vma_text_start) { *(.text.init) *(.*text*) }
  . = ALIGN(8);
  __lma_data_start = .;
  .data __vma_data_start_32 : AT(__lma_data_start) {
    __data_start = .;
    *(.*data*);
    PROVIDE_HIDDEN (__preinit_array_start = .);
    KEEP (*(.preinit_array))
    PROVIDE_HIDDEN (__preinit_array_end = .);

    PROVIDE_HIDDEN (__init_array_start = .);
    KEEP (*(SORT(.init_array.*)))
    KEEP (*(.init_array ))
    PROVIDE_HIDDEN (__init_array_end = .);

    PROVIDE_HIDDEN (__fini_array_start = .);
    KEEP (*(SORT(.fini_array.*)))
    KEEP (*(.fini_array ))
    PROVIDE_HIDDEN (__fini_array_end = .);

    *(.eh_frame);
  }
  . = ALIGN(8);
  __vma_data_end = .;

  /* The linker uses the __global_pointer$ symbol definition to compare the memory addresses and,
  if within range, it replaces absolute/pc-relative addressing with gp-relative addressing,
  which makes the code more efficient. */
  __global_pointer$ = __data_start + 0x800;

  . = ALIGN(8);
  __bss_start = .;
  .sbss : {
    *(.sbss .sbss.* .gnu.linkonce.sb.*)
    *(.scommon)
  }
  .bss : { *(.bss) }
  . = ALIGN(8);
  __bss_end = .;
  __vma_brk_start = .;
}
