#include "novgorod.h"
#include "types.h"
#include "periph.h"
#include "uart.h"


UART_TypeDef * UartModeInit()
{
  PORT_TypeDef * Port;
  RST_CLK->PER2_CLOCK = mask_PCLK_UART1 | mask_PCLK_PORTB | mask_PCLK_EEPROM | mask_PCLK_RST_CLK;
  RST_CLK->UART_CLOCK = RST_CLK_UART_CLOCK_UART1_CLK_EN;

  Port = PORTB;
  Port->OE = 0;
  Port->FUNC = (1 << PORT_FUNC_MODE0_OFFS) | (1 << PORT_FUNC_MODE1_OFFS);
  Port->ANALOG = mask_PORT0 | mask_PORT1;
  Port->PULL = 0;
  Port->PD = 0;
  Port->PWR = 2 << PORT_PWR_PWR0_OFFS;
  Port->OE = mask_PORT0;
  return UART1;
}


void UartSetBaud(UART_TypeDef * uart, u32 divider)
{
  while (uart->FR & UART_FR_BUSY);   //correction from Dyachkov insted uart->FR & UART_FR_TXFE
  uart->CR = 0;
  uart->IBRD = divider >> 6;
  uart->FBRD = divider & 0x3F;
  uart->LCR_H = (3 << UART_LCR_H_WLEN_OFFS);
  uart->CR = UART_MODE_TEST;
}


void UartSendByte(UART_TypeDef * uart, u32 ch)
{
  u32 tmp;
  while ( (tmp = uart->FR) & UART_FR_TXFF )
    if ( tmp & UART_FR_RXFF )
      uart->DR;
  uart->DR = ch;
}


u32 UartReceiveByte(UART_TypeDef * uart)
{
  while ( uart->FR & UART_FR_RXFE );
  return (uart->DR << 20) >> 20;
}


u32 UartSyncErr(UART_TypeDef * uart)
{
  u32 i;
  for ( i = 0; i < 16; i++ )
  {
    while ( (uart->FR & UART_FR_RXFE) );
    if ( (uart->DR & 0xFFF) != CMD_SYNC )
      return 1;
  }
  return 0;
}


u32 UartReceiveParam(UART_TypeDef * uart)
{
  u32 tmp, res;
  for ( tmp = 0; tmp < 0x4000; tmp+=0x1000 )
  {
    while ( uart->FR & UART_FR_RXFE );
    tmp |= uart->DR & 0xFFF;
    res = (res >> 8) | (tmp << 24);
    tmp &= ~0xFF;
  }
  return (tmp & 0xF00) ? ~0L : res;
}



void AF_Run(void *entry_point)
{
	asm("mv t0,%[src]" : : [src] "r" (entry_point));
	asm("jr  t0");
}


#define RAM_ADDR                0x20000000
#define RAM_SIZE                0x8000



typedef enum
{
  mode_MCU = 0,
  mode_UART0,
  mode_UART1,
  mode_RAM
} modes;



void InitPort(PORT_TypeDef * Port)
{
  Port->OE     = 0;
  Port->FUNC   = 0;
  Port->ANALOG =  mask_BOOT_PORT;
  Port->PULL   =  mask_BOOT_PORT;
  Port->PD     = 0;
  Port->PWR    = 0;
}


int main()
{
  u32 i;
  u32 Mode;
  u32 BKP_LDO;
  u32 tmp;

  RST_CLK->PER2_CLOCK = mask_PCLK_RST_CLK | mask_PCLK_BKP | mask_PCLK_PORTC;
  BKP_LDO = BKP->BKP_LDO;
  if ((BKP_LDO & (1<<25))==(1<<25))
    Mode = (BKP_LDO >> 27) & 3;
  else
  {
  InitPort(PORTC);
  for ( i = 0; i < 100; i ++ ) *(vu32 *)0;   
  Mode=0;
  Mode = (PORTC->RXTX) & mask_BOOT_MODE;
  PORTC->PULL   = 0;
  PORTC->ANALOG = 0;
  PORTC->PWR    = 0;
  BKP->BKP_WPR=0x8555AAA1;
  BKP->BKP_LDO=(BKP_LDO & (~(3<<27))) | (Mode<<27) | 1<<25;
  BKP->BKP_WPR=0;
  }
  switch ( Mode )
  {
    case mode_MCU :
    {
    	RST_CLK->PER2_CLOCK = mask_PCLK_RST_CLK;
      	asm("lui t0,0x10000");
	asm("jr  t0");	  
    }
    
    case mode_RAM:
    {
    	RST_CLK->PER2_CLOCK = mask_PCLK_RST_CLK;
        asm("lui t0,0x80000");
	asm("jr  t0");	
    }

    case mode_UART0 :
    case mode_UART1 :
    {
      u32 divisor, div_lo;
      u32 err;
      u32 sym;
      UART_TypeDef * Uart;

      Uart = UartModeInit();

      do {
        div_lo = divisor = DIV_MIN;
        for ( ; (divisor < DIV_MAX) && (divisor - div_lo < DIV_DLT*WO_ERR_CNT); )
        {
          UartSetBaud(Uart, divisor);
          UartReceiveByte(Uart);
          divisor += DIV_DLT;
          if ( UartSyncErr(Uart) ) { div_lo = divisor; }
        }
      } while ( divisor - div_lo < DIV_DLT*WO_ERR_CNT );

      for ( ; divisor < DIV_MAX; divisor += DIV_DLT )
      {
        UartSetBaud(Uart, divisor);
        UartReceiveByte(Uart);
        if ( UartSyncErr(Uart) ) break;
      }
      divisor = (div_lo + divisor) >> 1;
      UartSetBaud(Uart, divisor);
      for ( i = 0; i < 16; i++ )
        UartReceiveByte(Uart);
      sym = CMD_CR;

      for (;;)
      {
        err = 0;
        if ( sym >> 8 ) err = ERR_CHN;
        if ( !err ) switch ( sym )
        {
          case CMD_SYNC : break;
          case CMD_CR :
            UartSendByte(Uart, 0x0D);
            UartSendByte(Uart, 0x0A);
            UartSendByte(Uart, '>');
            break;

#ifdef CMD_BAUD
          case CMD_BAUD :
          {
            tmp = UartReceiveParam(Uart);
            if ( tmp == ~0L ) { err = ERR_CHN;  break; }

            if ( !tmp )      { err = ERR_BAUD; break; }

            tmp = ((u32)(divisor * BAUD_RATE)) / tmp;

            if ( (tmp < 64) || (tmp >= (1<<22)) ) { err = ERR_BAUD; break; }

            UartSendByte(Uart, CMD_BAUD);
            UartSetBaud(Uart, tmp);
            break;
          }
#endif

          case CMD_LOAD :
          case CMD_VFY :
          {
            u32 addr, size;
            addr = UartReceiveParam(Uart);
            size = UartReceiveParam(Uart);
            if ( (addr == ~0L) || (size == ~0L) ) { err = ERR_CHN; break; }
            UartSendByte(Uart, sym);

#ifdef __ENA_CHECK_PRMS__
            if ( (addr < RAM_ADDR) || (addr >= RAM_ADDR + RAM_SIZE) ) { err = ERR_ADDR; break; }
            if ( (size == 0) || (size > RAM_SIZE) ) { err = ERR_SIZE; break; }
#endif
            size += addr;
            for ( ; addr < size; addr++ )
              if ( sym == CMD_VFY )
                UartSendByte(Uart, *(u8 *)addr);
              else
              {
                u32 tmp = UartReceiveByte(Uart);
                if ( tmp >> 8 ) { err = ERR_CHN; break; }
                *(u8 *)addr = tmp;
              }
            if ( err ) break;
            UartSendByte(Uart, REPLY_OK);
            break;
          }

          case CMD_RUN :
          {
            u32 tmp = UartReceiveParam(Uart);
            if ( tmp == ~0L ) { err = ERR_CHN; break; }
            UartSendByte(Uart, CMD_RUN);
#ifdef __ENA_CHECK_PRMS__
            {
              u32 sptr, addr;
              sptr = *(u32 *)tmp;
              if ( (sptr < RAM_ADDR) || (sptr >= RAM_ADDR + RAM_SIZE) || (sptr & 3) ) { err = ERR_SPTR; break; }
              addr = *((u32 *)tmp + 1);
              if ( (addr < RAM_ADDR) || (addr >= RAM_ADDR + RAM_SIZE) || !(addr & 1) ) { err = ERR_ADDR; break; }
            }
#endif           
			AF_Run((void *)tmp);
          }

          default : err = ERR_CMD;
        }

        if ( err )
        {
          UartSendByte(Uart, REPLY_ERR);
        }

        sym = UartReceiveByte(Uart);
      }
    }
  }
  while ( 1 );
}


