/**
  ******************************************************************************
  * @file    NOVGOROD.h
  * @author  Phyton Application Team
  * @version V1.0.0
  * @date
  * @brief   This file contains all the Special Function Registers definitions
  *          for the Milandr NOVGOROD microcontroller.
  ******************************************************************************
  * @copy
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, PHYTON SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT
  * OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2010 Phyton</center></h2>
  ******************************************************************************
  * FILE NOVGOROD.h
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __NOVGOROD_H
#define __NOVGOROD_H

/** @addtogroup __CMSIS CMSIS
  * @{
  */

/** @defgroup __NOVGOROD NOVGOROD
  * @{
  */

/* Includes ------------------------------------------------------------------*/

#include "stdint.h"
#include "novgorod_otp_defs.h"
#include "novgorod_spi_defs.h"
#include "novgorod_uart_defs.h"
#include "novgorod_eeprom_defs.h"
#include "novgorod_rst_clk_defs.h"
#include "novgorod_dma_defs.h"
#include "novgorod_i2c_defs.h"
#include "novgorod_usart_defs.h"
#include "novgorod_dac_defs.h"
#include "novgorod_adc_defs.h"
#include "novgorod_wwdg_defs.h"
#include "novgorod_iwdg_defs.h"
#include "novgorod_power_defs.h"
#include "novgorod_bkp_defs.h"
#include "novgorod_adciu_defs.h"
#include "novgorod_timer_defs.h"
#include "novgorod_port_defs.h"
#include "novgorod_crc_defs.h"
#include "novgorod_crypto_defs.h"

/** @defgroup __Peripheral_Memory_Map Peripheral Memory Map
  * @{
  */
#define OTP_BASE              ((uint32_t)0x70000000U) 
#define OTP_MEM_BASE          (OTP_BASE)
#define OTP_REGS_BASE         (OTP_BASE + 0x00010000)

#define SPI1_BASE             0x40000000
#define UART1_BASE            0x40008000
#define UART2_BASE            0x40010000
#define EEPROM_BASE           0x40018000
#define RST_CLK_BASE          0x40020000
#define DMA_BASE              0x40028000
#define I2C_BASE              0x40030000
#define UART3_BASE            0x40038000
#define ADC_BASE              0x40040000
#define WWDG_BASE             0x40048000
#define IWDG_BASE             0x40050000
#define POWER_BASE            0x40058000
#define BKP_BASE              0x40060000
#define ADCIU_BASE            0x40068000
#define TIMER1_BASE           0x40070000
#define TIMER2_BASE           0x40078000
#define PORTA_BASE            0x40080000
#define PORTB_BASE            0x40088000
#define PORTC_BASE            0x40090000
#define CRC_BASE              0x40098000
#define NOISE_GEN_BASE        0x400A0000
#define SENSORS_BASE          0x400A8000
#define CLK_MEASURE_BASE      0x400B0000
#define RANDOM_BASE           0x400B8000
#define ISO7816_BASE          0x400C0000
#define SPI2_BASE             0x400C8000
#define SPI3_BASE             0x400D0000
#define TIMER3_BASE           0x400D8000
#define TIMER4_BASE           0x400E0000
#define UART4_BASE            0x400E8000
#define PORTD_BASE            0x400F0000
#define ALU_BASE              0x60000000
#define L_BLOCK_BASE          0x60004000
#define S_BLOCK0_BASE         0x60008000
#define S_BLOCK1_BASE         0x6000C000
#define S_BLOCK2_BASE         0x60010000
#define S_BLOCK3_BASE         0x60014000
#define S_BLOCK4_BASE         0x60018000
#define S_BLOCK5_BASE         0x6001C000
#define S_BLOCK6_BASE         0x60020000
#define S_BLOCK7_BASE         0x60024000
#define P_BYTE_BASE           0x60028000
#define P_BIT0_BASE           0x6002C000
#define P_BIT1_BASE           0x60030000
#define P_BIT2_BASE           0x60034000
#define P_BIT3_BASE           0x60038000

/** @} */ /* End of group __Peripheral_Memory_Map */

/** @defgroup __Peripheral_declaration Peripheral declaration
  * @{
  */
#define OTP_MEM               ((uint32_t 	      *)OTP_MEM_BASE      )
#define OTP_REG               ((OTP_TypeDef 	      *)OTP_REGS_BASE	  )
#define SPI1                  ((SPI_TypeDef           *)SPI1_BASE         )
#define UART1                 ((UART_TypeDef          *)UART1_BASE        )
#define UART2                 ((UART_TypeDef          *)UART2_BASE        )
#define EEPROM                ((EEPROM_TypeDef        *)EEPROM_BASE       )
#define RST_CLK               ((RST_CLK_TypeDef       *)RST_CLK_BASE      )
#define DMA                   ((DMA_TypeDef           *)DMA_BASE          )
#define I2C                   ((I2C_TypeDef           *)I2C_BASE          )
#define UART3                 ((UART_TypeDef          *)UART3_BASE        )
#define ADC                   ((ADC_TypeDef           *)ADC_BASE          )
#define WWDG                  ((WWDG_TypeDef          *)WWDG_BASE         )
#define IWDG                  ((IWDG_TypeDef          *)IWDG_BASE         )
#define POWER                 ((POWER_TypeDef         *)POWER_BASE        )
#define BKP                   ((BKP_TypeDef           *)BKP_BASE          )
#define ADCIU                 ((ADCIU_TypeDef         *)ADCIU_BASE        )
#define TIMER1                ((TIMER_TypeDef         *)TIMER1_BASE       )
#define TIMER2                ((TIMER_TypeDef         *)TIMER2_BASE       )
#define PORTA                 ((PORT_TypeDef          *)PORTA_BASE        )
#define PORTB                 ((PORT_TypeDef          *)PORTB_BASE        )
#define PORTC                 ((PORT_TypeDef          *)PORTC_BASE        )
#define CRC                   ((CRC_TypeDef           *)CRC_BASE          )
#define NOISE_GEN             ((NOISE_GEN_TypeDef     *)NOISE_GEN_BASE    )
#define SENSORS               ((SENSORS_TypeDef       *)SENSORS_BASE      )
#define CLK_MEASURE           ((CLK_MEASURE_TypeDef   *)CLK_MEASURE_BASE  )
#define RANDOM                ((RANDOM_TypeDef        *)RANDOM_BASE       )
#define USART                 ((USART_TypeDef         *)ISO7816_BASE      )
#define SPI2                  ((SPI_TypeDef           *)SPI2_BASE         )
#define SPI3                  ((SPI_TypeDef           *)SPI3_BASE         )
#define TIMER3                ((TIMER_TypeDef         *)TIMER3_BASE       )
#define TIMER4                ((TIMER_TypeDef         *)TIMER4_BASE       )
#define UART4                 ((UART_TypeDef          *)UART4_BASE        )
#define PORTD                 ((PORT_TypeDef          *)PORTD_BASE        )
#define ALU                   ((ALU_TypeDef           *)ALU_BASE          )
#define L_BLOCK               ((L_BLOCK_TypeDef       *)L_BLOCK_BASE      )
#define S_BLOCK0              ((S_BLOCK_TypeDef       *)S_BLOCK0_BASE     )
#define S_BLOCK1              ((S_BLOCK_TypeDef       *)S_BLOCK1_BASE     )
#define S_BLOCK2              ((S_BLOCK_TypeDef       *)S_BLOCK2_BASE     )
#define S_BLOCK3              ((S_BLOCK_TypeDef       *)S_BLOCK3_BASE     )
#define S_BLOCK4              ((S_BLOCK_TypeDef       *)S_BLOCK4_BASE     )
#define S_BLOCK5              ((S_BLOCK_TypeDef       *)S_BLOCK5_BASE     )
#define S_BLOCK6              ((S_BLOCK_TypeDef       *)S_BLOCK6_BASE     )
#define S_BLOCK7              ((S_BLOCK_TypeDef       *)S_BLOCK7_BASE     )
#define P_BYTE                ((P_BYTE_TypeDef        *)P_BYTE_BASE       )
#define P_BIT0                ((P_BIT_TypeDef         *)P_BIT0_BASE       )
#define P_BIT1                ((P_BIT_TypeDef         *)P_BIT1_BASE       )
#define P_BIT2                ((P_BIT_TypeDef         *)P_BIT2_BASE       )
#define P_BIT3                ((P_BIT_TypeDef         *)P_BIT3_BASE       )

/** @} */ /* End of group __Peripheral_declaration */

/** @} */ /* End of group __NOVGOROD */

/** @} */ /* End of group __CMSIS */

#endif /* __NOVGOROD_H */

/******************* (C) COPYRIGHT 2010 Phyton *********************************
*
* END OF FILE NOVGOROD.h */
