/**
  ******************************************************************************
  * @file    novgorod_adciu_defs.h
  * @author  Phyton Application Team
  * @version V1.0.0
  * @date
  * @brief   This file contains all the Special Function Registers definitions
  *          for the ADCIU peripheral unit used in the Milandr NOVGOROD
  *          microcontrollers.
  ******************************************************************************
  * @copy
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, PHYTON SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT
  * OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2010 Phyton</center></h2>
  ******************************************************************************
  * FILE novgorod_adciu_defs.h
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __NOVGOROD_ADCIU_DEFS_H
#define __NOVGOROD_ADCIU_DEFS_H

/** @addtogroup __CMSIS CMSIS
  * @{
  */

/** @addtogroup __NOVGOROD_Peripheral_Units NOVGOROD Peripheral Units
  * @{
  */

/** @defgroup Periph_ADCIU ADCIU
  * @{
  */

/** @defgroup Periph_ADCIU_Data_Structures Data Structures
  * @{
  */

/** @defgroup Periph_ADCIU_TypeDef ADCIU_TypeDef
  * @{
  */
typedef struct {
  __IO uint32_t CTR;
  __IO uint32_t WC;
  __IO uint32_t WATTP;
  __IO uint32_t WATTN;
  __IO uint32_t VC;
  __IO uint32_t VARP;
  __IO uint32_t VARN;
  __IO uint32_t AC;
  __IO uint32_t VR;
  __IO uint32_t MD0;
  __IO uint32_t MD1;
  __IO uint32_t VPEAK;
  __IO uint32_t IPEAK;
  __IO uint32_t VDAT;
  __IO uint32_t I0DAT;
  __IO uint32_t I3DAT;
  __IO uint32_t VRMS;
  __IO uint32_t VRMS2;
  __IO uint32_t IRMS;
  __IO uint32_t IRMS2;
  __IO uint32_t STAT;
  __IO uint32_t MASK;
} __AUICF0;

typedef struct {
  __IO uint32_t CTR;
  __IO uint32_t WC;
  __IO uint32_t WATTP;
  __IO uint32_t WATTN;
  __IO uint32_t VC;
  __IO uint32_t VARP;
  __IO uint32_t VARN;
  __IO uint32_t AC;
  __IO uint32_t VR;
  __IO uint32_t MD0;
  __IO uint32_t MD1;
  __IO uint32_t MD2;
  __IO uint32_t VPEAK;
  __IO uint32_t IPEAK;
  __IO uint32_t VDAT;
  __IO uint32_t IDAT;
  __IO uint32_t VRMS;
  __IO uint32_t VRMS2;
  __IO uint32_t IRMS;
  __IO uint32_t IRMS2;
  __IO uint32_t STAT;
  __IO uint32_t MASK;
} __AUICF1;

typedef struct {
  __IO uint32_t CTRL1;
  __IO uint32_t CTRL2;
  __IO uint32_t CTRL3;
  __AUICF0 F0;
  __AUICF1 F1;
  __AUICF1 F2;
  __IO uint32_t CCAL1;
  __IO uint32_t CCAL2;
  __IO uint32_t CCAL3;
  __IO uint32_t CCAL4;
  __IO uint32_t F0IRMS_INACTIVE;
  __IO uint32_t F0WATTP_L;
  __IO uint32_t F0WATTN_L;
  __IO uint32_t F0VARP_L;
  __IO uint32_t F0VARN_L; 
  __IO uint32_t F0VR_L;
  __IO uint32_t F1WATTP_L;
  __IO uint32_t F1WATTN_L;
  __IO uint32_t F1VARP_L;
  __IO uint32_t F1VARN_L; 
  __IO uint32_t F1VR_L;
  __IO uint32_t F2WATTP_L;
  __IO uint32_t F2WATTN_L;
  __IO uint32_t F2VARP_L;
  __IO uint32_t F2VARN_L; 
  __IO uint32_t F2VR_L;
} ADCIU_TypeDef;

/** @} */ /* End of group Periph_ADCIU_TypeDef */

/** @} */ /* End of group Periph_ADCIU_Data_Structures */

/** @} */ /* End of group Periph_ADCIU */

/** @} */ /* End of group __NOVGOROD_Peripheral_Units */

/** @} */ /* End of group __CMSIS */

#endif /* __NOVGOROD_ADCIU_DEFS_H */

/******************* (C) COPYRIGHT 2010 Phyton *********************************
*
* END OF FILE novgorod_adciu_defs.h */
