/**
  ******************************************************************************
  * @file    novgorod_bkp_defs.h
  * @author  Phyton Application Team
  * @version V1.0.0
  * @date
  * @brief   This file contains all the Special Function Registers definitions
  *          for the BKP peripheral unit used in the Milandr NOVGOROD
  *          microcontrollers.
  ******************************************************************************
  * @copy
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, PHYTON SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT
  * OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2010 Phyton</center></h2>
  ******************************************************************************
  * FILE novgorod_bkp_defs.h
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __NOVGOROD_BKP_DEFS_H
#define __NOVGOROD_BKP_DEFS_H

/** @addtogroup __CMSIS CMSIS
  * @{
  */

/** @addtogroup __NOVGOROD_Peripheral_Units NOVGOROD Peripheral Units
  * @{
  */

/** @defgroup Periph_BKP BKP
  * @{
  */

/** @defgroup Periph_BKP_Data_Structures Data Structures
  * @{
  */

/** @defgroup Periph_BKP_TypeDef BKP_TypeDef
  * @{
  */

typedef struct {
  __IO uint32_t BKP_WPR;
  __IO uint32_t BKP_LDO;
  __IO uint32_t BKP_CLK;
  __IO uint32_t BKP_RTC;
  __IO uint32_t RTC_WUTR;
  __IO uint32_t RTC_PREDIV;
  __IO uint32_t RTC_PRL;
  __IO uint32_t RTC_ALRM;
  __IO uint32_t RTC_CS;
  __IO uint32_t RTC_TR;
  __IO uint32_t RTC_DR;
  __IO uint32_t RTC_ALRMAR;
  __IO uint32_t RTC_ALRMBR;
  __IO uint32_t RTC_TSTR1;
  __IO uint32_t RTC_TSTR2;
  __IO uint32_t RTC_TSTR3;
  __IO uint32_t RTC_TSDR1;
  __IO uint32_t RTC_TSDR2;
  __IO uint32_t RTC_TSDR3;
  __IO uint32_t RTC_TAFCR;
} BKP_TypeDef;

#define BKP_MEM (((volatile unsigned long *) 0x40061000))

/** @} */ /* End of group Periph_BKP_TypeDef */

/** @} */ /* End of group Periph_BKP_Data_Structures */

/** @defgroup Periph_BKP_Defines Defines
  * @{
  */

/** @defgroup Periph_BKP_BKP_REG_0E_Bits BKP_REG_0E
  * @{
  */

#define LOW_OFFS                     0
#define LOW_MASK                     ((uint32_t)0x00000007)

#define SelectRI_OFFS                3
#define SelectRI_MASK                ((uint32_t)0x00000038)

#define JTAGA_OFFS                   6
#define JTAGA                        ((uint32_t)0x00000040)

#define JTAGB_OFFS                   7
#define JTAGB                        ((uint32_t)0x00000080)

#define Trim_OFFS                    8
#define Trim_MASK                    ((uint32_t)0x00000700)

#define FPOR_OFFS                    11
#define FPOR                         ((uint32_t)0x00000800)

#define BKP_REG_OFFS                 12
#define BKP_REG_MASK                 ((uint32_t)0xFFFFF000)


/** @} */ /* End of group Periph_BKP_BKP_REG_0E_Bits */

/** @} */ /* End of group Periph_BKP_Defines */

/** @defgroup Periph_BKP_Defines Defines
  * @{
  */

/** @defgroup Periph_BKP_BKP_REG_0F_Bits BKP_REG_0F
  * @{
  */

#define LSE_ON_OFFS                  0
#define LSE_ON                       ((uint32_t)0x00000001)

#define LSE_BYP_OFFS                 1
#define LSE_BYP                      ((uint32_t)0x00000002)

#define RTC_SEL_OFFS                 2
#define RTC_SEL_MASK                 ((uint32_t)0x0000000C)

#define RTC_EN_OFFS                  4
#define RTC_EN                       ((uint32_t)0x00000010)

#define CAL_OFFS                     5
#define CAL_MASK                     ((uint32_t)0x00001FE0)

#define LSE_RDY_OFFS                 13
#define LSE_RDY                      ((uint32_t)0x00002000)


#define LSI_ON_OFFS                  15
#define LSI_ON                       ((uint32_t)0x00008000)

#define LSI_TRIM_OFFS                16
#define LSI_TRIM_MASK                ((uint32_t)0x001F0000)

#define LSI_RDY_OFFS                 21
#define LSI_RDY                      ((uint32_t)0x00200000)

#define HSI_ON_OFFS                  22
#define HSI_ON                       ((uint32_t)0x00400000)

#define HSI_RDY_OFFS                 23
#define HSI_RDY                      ((uint32_t)0x00800000)

#define HSI_TRIM_OFFS                24
#define HSI_TRIM_MASK                ((uint32_t)0x3F000000)

#define STANDBY_OFFS                 30
#define STANDBY                      ((uint32_t)0x40000000)

#define RTC_RESET_OFFS               31
#define RTC_RESET                    ((uint32_t)0x80000000)


/** @} */ /* End of group Periph_BKP_BKP_REG_0F_Bits */

/** @} */ /* End of group Periph_BKP_Defines */

/** @defgroup Periph_BKP_Defines Defines
  * @{
  */

/** @defgroup Periph_BKP_BKP_RTC_CS_Bits BKP_RTC_CS
  * @{
  */

#define OWF_OFFS                     0
#define OWF                          ((uint32_t)0x00000001)

#define SECF_OFFS                    1
#define SECF                         ((uint32_t)0x00000002)

#define ALRF_OFFS                    2
#define ALRF                         ((uint32_t)0x00000004)

#define OWF_IE_OFFS                  3
#define OWF_IE                       ((uint32_t)0x00000008)

#define SECF_IE_OFFS                 4
#define SECF_IE                      ((uint32_t)0x00000010)

#define ALRF_IE_OFFS                 5
#define ALRF_IE                      ((uint32_t)0x00000020)

#define WEC_OFFS                     6
#define WEC                          ((uint32_t)0x00000040)


/** @} */ /* End of group Periph_BKP_BKP_RTC_CS_Bits */

/** @} */ /* End of group Periph_BKP_Defines */

/** @} */ /* End of group Periph_BKP */

/** @} */ /* End of group __NOVGOROD_Peripheral_Units */

/** @} */ /* End of group __CMSIS */

#endif /* __NOVGOROD_BKP_DEFS_H */

/******************* (C) COPYRIGHT 2010 Phyton *********************************
*
* END OF FILE novgorod_bkp_defs.h */
