/*
 * ==========================================================================
 * -------------------------- OTP registers ---------------------------------
 * ==========================================================================
 */
typedef struct
{
  __IO uint32_t STAT_CTRL;        /*!< Status and control register           Address offset: 0x00 */
  __IO uint32_t STAT;             /*!< Status register                       Address offset: 0x04 */
  __IO uint32_t DELAY_0;          /*!< Delay 0 register                      Address offset: 0x08 */
  __IO uint32_t DELAY_1;          /*!< Delay 1 register                      Address offset: 0x0C */
  __IO uint32_t RW_CMD;           /*!< Read/write command register           Address offset: 0x10 */
  __IO uint32_t READ_DATA;        /*!< Read data register                    Address offset: 0x14 */
  __IO uint32_t WRITE_PROTECT;    /*!< Write protect register                Address offset: 0x18 */
  __IO uint32_t READ_PROTECT;     /*!< Read protect register                 Address offset: 0x1C */
  __IO uint32_t DIR_CTRL;         /*!< Direct control register               Address offset: 0x20 */
  __IO uint32_t DIR_DATA;         /*!< Direct data register                  Address offset: 0x24 */
  __IO uint32_t TEST_OPT;         /*!< Test options register                 Address offset: 0x28 */
} OTP_TypeDef;

/*                                 
 * ==========================================================================
 * ------------------------ OTP registers bits ------------------------------
 * ==========================================================================
 */
/*< Status and control register */
#define OTP_FSM_STATE_MASK          ((uint32_t)0x00000007)      /*< Fsm state mask                       */
#define OTP_FSM_IDLE                ((uint32_t)0x00000000)      /*< Fsm idle state                       */
#define OTP_FSM_INIT                ((uint32_t)0x00000001)      /*< Fsm init state                       */
#define OTP_FSM_READY               ((uint32_t)0x00000002)      /*< Fsm ready state                      */
#define OTP_FSM_REG_READ_PENDING    ((uint32_t)0x00000003)      /*< Fsm read via registers pending state */
#define OTP_FSM_BUS_READ_PENDING    ((uint32_t)0x00000004)      /*< Fsm read via bus pending state       */
#define OTP_FSM_WRITE_PENDING       ((uint32_t)0x00000005)      /*< Fsm write pending state              */
#define OTP_FSM_DIR_CTRL            ((uint32_t)0x00000006)      /*< Fsm direct control state             */

#define OTP_BUSY                    ((uint32_t)0x00000008)      /*< OTP is busy                                     */
#define OTP_LOCK                    ((uint32_t)0x00000010)      /*< Entire OTP write lock                           */
#define OTP_PLOCK                   ((uint32_t)0x00000020)      /*< Partly OTP write lock                           */
#define OTP_RWERROR                 ((uint32_t)0x00000040)      /*< Read/write error                                */
#define OTP_TEST_CRC                ((uint32_t)0x00000080)      /*< Special test data integrity signal              */
#define OTP_READ_PCRC               ((uint32_t)0x00000100)      /*< Read protection register data integrity signal  */
#define OTP_WRITE_PCRC              ((uint32_t)0x00000200)      /*< Write protection register data integrity signal */
#define OTP_DIR_EN                  ((uint32_t)0x00000400)      /*< Direct control request bit                      */
#define OTP_DIR_ACK                 ((uint32_t)0x00000800)      /*< Direct control acknowledge bit                  */
#define OTP_DIR_ERR                 ((uint32_t)0x00001000)      /*< Direct control error bit                        */

/*< Blocks status register */
#define OTP_0_FSM_STATE_MASK                ((uint32_t)0x0000001F)      /*< OTP0 block fsm state mask                                 */
#define OTP_0_FSM_IDLE                      ((uint32_t)0x00000000)      /*< OTP0 block fsm idle state                                 */
#define OTP_0_FSM_ENERGY_SAVE_PENDING       ((uint32_t)0x00000001)      /*< OTP0 block fsm energy save pending state                  */
#define OTP_0_FSM_RESET_PENDING             ((uint32_t)0x00000002)      /*< OTP0 block fsm reset pending state                        */
#define OTP_0_FSM_RESET                     ((uint32_t)0x00000003)      /*< OTP0 block fsm reset state                                */
#define OTP_0_FSM_RESET_ENDING              ((uint32_t)0x00000004)      /*< OTP0 block fsm reset finalization state                   */
#define OTP_0_FSM_ACTIVE                    ((uint32_t)0x00000005)      /*< OTP0 block fsm active state. Read/write pending           */
#define OTP_0_FSM_PAUSE                     ((uint32_t)0x00000006)      /*< OTP0 block fsm pause state. After write                   */
#define OTP_0_FSM_READ_PENDING              ((uint32_t)0x00000007)      /*< OTP0 block fsm read pending state                         */
#define OTP_0_FSM_READ                      ((uint32_t)0x00000008)      /*< OTP0 block fsm read state                                 */
#define OTP_0_FSM_READ_ENDING               ((uint32_t)0x00000009)      /*< OTP0 block fsm read finalization state                    */
#define OTP_0_FSM_WRITE_PENDING             ((uint32_t)0x0000000A)      /*< OTP0 block fsm write pending state                        */
#define OTP_0_FSM_WRITE_DATA_SAVE           ((uint32_t)0x0000000B)      /*< OTP0 block fsm saving data state                          */
#define OTP_0_FSM_WRITE_DATA_SAVE_ENDING    ((uint32_t)0x0000000C)      /*< OTP0 block fsm finalization of saving data state          */
#define OTP_0_FSM_PROGR_PENDING             ((uint32_t)0x0000000D)      /*< OTP0 block fsm programming pending state                  */
#define OTP_0_FSM_HIGH_VOLTAGE_PENDING      ((uint32_t)0x0000000E)      /*< OTP0 block fsm voltage increase circuit preparing state   */
#define OTP_0_FSM_PROGR                     ((uint32_t)0x0000000F)      /*< OTP0 block fsm programming state                          */
#define OTP_0_FSM_HIGH_VOLTAGE_ENDING       ((uint32_t)0x00000010)      /*< OTP0 block fsm voltage increase circuit turning off state */
#define OTP_0_FSM_PROGR_ENDING              ((uint32_t)0x00000011)      /*< OTP0 block fsm programming finalization state             */
#define OTP_0_FSM_WRITE_ENDING              ((uint32_t)0x00000012)      /*< OTP0 block fsm write finalization state                   */
#define OTP_0_FSM_DIR_CTRL_PENDING          ((uint32_t)0x00000013)      /*< OTP0 block fsm direct control pending state               */
#define OTP_0_FSM_DIR_CTRL                  ((uint32_t)0x00000014)      /*< OTP0 block fsm direct control state                       */
                                                                        /*< 0x00000020 - reserved                                     */
#define OTP_0_LOCK                          ((uint32_t)0x00000040)      /*< OTP0 block is locked for writing                          */
#define OTP_0_BUSY                          ((uint32_t)0x00000080)      /*< OTP0 block is busy                                        */

#define OTP_1_FSM_STATE_MASK                ((uint32_t)0x00001F00)      /*< OTP1 block fsm state mask                                 */
#define OTP_1_FSM_IDLE                      ((uint32_t)0x00000000)      /*< OTP1 block fsm idle state                                 */
#define OTP_1_FSM_ENERGY_SAVE_PENDING       ((uint32_t)0x00000100)      /*< OTP1 block fsm energy save pending state                  */
#define OTP_1_FSM_RESET_PENDING             ((uint32_t)0x00000200)      /*< OTP1 block fsm reset pending state                        */
#define OTP_1_FSM_RESET                     ((uint32_t)0x00000300)      /*< OTP1 block fsm reset state                                */
#define OTP_1_FSM_RESET_ENDING              ((uint32_t)0x00000400)      /*< OTP1 block fsm reset finalization state                   */
#define OTP_1_FSM_ACTIVE                    ((uint32_t)0x00000500)      /*< OTP1 block fsm active state. Read/write pending           */
#define OTP_1_FSM_PAUSE                     ((uint32_t)0x00000600)      /*< OTP1 block fsm pause state. After write                   */
#define OTP_1_FSM_READ_PENDING              ((uint32_t)0x00000700)      /*< OTP1 block fsm read pending state                         */
#define OTP_1_FSM_READ                      ((uint32_t)0x00000800)      /*< OTP1 block fsm read state                                 */
#define OTP_1_FSM_READ_ENDING               ((uint32_t)0x00000900)      /*< OTP1 block fsm read finalization state                    */
#define OTP_1_FSM_WRITE_PENDING             ((uint32_t)0x00000A00)      /*< OTP1 block fsm write pending state                        */
#define OTP_1_FSM_WRITE_DATA_SAVE           ((uint32_t)0x00000B00)      /*< OTP1 block fsm saving data state                          */
#define OTP_1_FSM_WRITE_DATA_SAVE_ENDING    ((uint32_t)0x00000C00)      /*< OTP1 block fsm finalization of saving data state          */
#define OTP_1_FSM_PROGR_PENDING             ((uint32_t)0x00000D00)      /*< OTP1 block fsm programming pending state                  */
#define OTP_1_FSM_HIGH_VOLTAGE_PENDING      ((uint32_t)0x00000E00)      /*< OTP1 block fsm voltage increase circuit preparing state   */
#define OTP_1_FSM_PROGR                     ((uint32_t)0x00000F00)      /*< OTP1 block fsm programming state                          */
#define OTP_1_FSM_HIGH_VOLTAGE_ENDING       ((uint32_t)0x00001000)      /*< OTP1 block fsm voltage increase circuit turning off state */
#define OTP_1_FSM_PROGR_ENDING              ((uint32_t)0x00001100)      /*< OTP1 block fsm programming finalization state             */
#define OTP_1_FSM_WRITE_ENDING              ((uint32_t)0x00001200)      /*< OTP1 block fsm write finalization state                   */
#define OTP_1_FSM_DIR_CTRL_PENDING          ((uint32_t)0x00001300)      /*< OTP1 block fsm direct control pending state               */
#define OTP_1_FSM_DIR_CTRL                  ((uint32_t)0x00001400)      /*< OTP1 block fsm direct control state                       */
                                                                        /*< 0x00002000 - reserved                                     */
#define OTP_1_LOCK                          ((uint32_t)0x00004000)      /*< OTP1 block is locked for writing                          */
#define OTP_1_BUSY                          ((uint32_t)0x00008000)      /*< OTP1 block is busy                                        */

#define OTP_2_FSM_STATE_MASK                ((uint32_t)0x001F0000)      /*< OTP2 block fsm state mask                                 */
#define OTP_2_FSM_IDLE                      ((uint32_t)0x00000000)      /*< OTP2 block fsm idle state                                 */
#define OTP_2_FSM_ENERGY_SAVE_PENDING       ((uint32_t)0x00010000)      /*< OTP2 block fsm energy save pending state                  */
#define OTP_2_FSM_RESET_PENDING             ((uint32_t)0x00020000)      /*< OTP2 block fsm reset pending state                        */
#define OTP_2_FSM_RESET                     ((uint32_t)0x00030000)      /*< OTP2 block fsm reset state                                */
#define OTP_2_FSM_RESET_ENDING              ((uint32_t)0x00040000)      /*< OTP2 block fsm reset finalization state                   */
#define OTP_2_FSM_ACTIVE                    ((uint32_t)0x00050000)      /*< OTP2 block fsm active state. Read/write pending           */
#define OTP_2_FSM_PAUSE                     ((uint32_t)0x00060000)      /*< OTP2 block fsm pause state. After write                   */
#define OTP_2_FSM_READ_PENDING              ((uint32_t)0x00070000)      /*< OTP2 block fsm read pending state                         */
#define OTP_2_FSM_READ                      ((uint32_t)0x00080000)      /*< OTP2 block fsm read state                                 */
#define OTP_2_FSM_READ_ENDING               ((uint32_t)0x00090000)      /*< OTP2 block fsm read finalization state                    */
#define OTP_2_FSM_WRITE_PENDING             ((uint32_t)0x000A0000)      /*< OTP2 block fsm write pending state                        */
#define OTP_2_FSM_WRITE_DATA_SAVE           ((uint32_t)0x000B0000)      /*< OTP2 block fsm saving data state                          */
#define OTP_2_FSM_WRITE_DATA_SAVE_ENDING    ((uint32_t)0x000C0000)      /*< OTP2 block fsm finalization of saving data state          */
#define OTP_2_FSM_PROGR_PENDING             ((uint32_t)0x000D0000)      /*< OTP2 block fsm programming pending state                  */
#define OTP_2_FSM_HIGH_VOLTAGE_PENDING      ((uint32_t)0x000E0000)      /*< OTP2 block fsm voltage increase circuit preparing state   */
#define OTP_2_FSM_PROGR                     ((uint32_t)0x000F0000)      /*< OTP2 block fsm programming state                          */
#define OTP_2_FSM_HIGH_VOLTAGE_ENDING       ((uint32_t)0x00100000)      /*< OTP2 block fsm voltage increase circuit turning off state */
#define OTP_2_FSM_PROGR_ENDING              ((uint32_t)0x00110000)      /*< OTP2 block fsm programming finalization state             */
#define OTP_2_FSM_WRITE_ENDING              ((uint32_t)0x00120000)      /*< OTP2 block fsm write finalization state                   */
#define OTP_2_FSM_DIR_CTRL_PENDING          ((uint32_t)0x00130000)      /*< OTP2 block fsm direct control pending state               */
#define OTP_2_FSM_DIR_CTRL                  ((uint32_t)0x00140000)      /*< OTP2 block fsm direct control state                       */
                                                                        /*< 0x00200000 - reserved                                     */
#define OTP_2_LOCK                          ((uint32_t)0x00400000)      /*< OTP2 block is locked for writing                          */
#define OTP_2_BUSY                          ((uint32_t)0x00800000)      /*< OTP2 block is busy                                        */

#define OTP_3_FSM_STATE_MASK                ((uint32_t)0x1F000000)      /*< OTP3 block fsm state mask                                 */
#define OTP_3_FSM_IDLE                      ((uint32_t)0x00000000)      /*< OTP3 block fsm idle state                                 */
#define OTP_3_FSM_ENERGY_SAVE_PENDING       ((uint32_t)0x01000000)      /*< OTP3 block fsm energy save pending state                  */
#define OTP_3_FSM_RESET_PENDING             ((uint32_t)0x02000000)      /*< OTP3 block fsm reset pending state                        */
#define OTP_3_FSM_RESET                     ((uint32_t)0x03000000)      /*< OTP3 block fsm reset state                                */
#define OTP_3_FSM_RESET_ENDING              ((uint32_t)0x04000000)      /*< OTP3 block fsm reset finalization state                   */
#define OTP_3_FSM_ACTIVE                    ((uint32_t)0x05000000)      /*< OTP3 block fsm active state. Read/write pending           */
#define OTP_3_FSM_PAUSE                     ((uint32_t)0x06000000)      /*< OTP3 block fsm pause state. After write                   */
#define OTP_3_FSM_READ_PENDING              ((uint32_t)0x07000000)      /*< OTP3 block fsm read pending state                         */
#define OTP_3_FSM_READ                      ((uint32_t)0x08000000)      /*< OTP3 block fsm read state                                 */
#define OTP_3_FSM_READ_ENDING               ((uint32_t)0x09000000)      /*< OTP3 block fsm read finalization state                    */
#define OTP_3_FSM_WRITE_PENDING             ((uint32_t)0x0A000000)      /*< OTP3 block fsm write pending state                        */
#define OTP_3_FSM_WRITE_DATA_SAVE           ((uint32_t)0x0B000000)      /*< OTP3 block fsm saving data state                          */
#define OTP_3_FSM_WRITE_DATA_SAVE_ENDING    ((uint32_t)0x0C000000)      /*< OTP3 block fsm finalization of saving data state          */
#define OTP_3_FSM_PROGR_PENDING             ((uint32_t)0x0D000000)      /*< OTP3 block fsm programming pending state                  */
#define OTP_3_FSM_HIGH_VOLTAGE_PENDING      ((uint32_t)0x0E000000)      /*< OTP3 block fsm voltage increase circuit preparing state   */
#define OTP_3_FSM_PROGR                     ((uint32_t)0x0F000000)      /*< OTP3 block fsm programming state                          */
#define OTP_3_FSM_HIGH_VOLTAGE_ENDING       ((uint32_t)0x10000000)      /*< OTP3 block fsm voltage increase circuit turning off state */
#define OTP_3_FSM_PROGR_ENDING              ((uint32_t)0x11000000)      /*< OTP3 block fsm programming finalization state             */
#define OTP_3_FSM_WRITE_ENDING              ((uint32_t)0x12000000)      /*< OTP3 block fsm write finalization state                   */
#define OTP_3_FSM_DIR_CTRL_PENDING          ((uint32_t)0x13000000)      /*< OTP3 block fsm direct control pending state               */
#define OTP_3_FSM_DIR_CTRL                  ((uint32_t)0x14000000)      /*< OTP3 block fsm direct control state                       */
                                                                        /*< 0x20000000 - reserved                                     */
#define OTP_3_LOCK                          ((uint32_t)0x40000000)      /*< OTP3 block is locked for writing                          */
#define OTP_3_BUSY                          ((uint32_t)0x80000000)      /*< OTP3 block is busy                                        */

/*< Read/write command register */
#define OTP_CMD_READ                        ((uint32_t)0x10000000)      /*< OTP read command                 */
#define OTP_CMD_WRITE                       ((uint32_t)0x20000000)      /*< OTP write command                */
#define OTP_CMD_RW_ERROR                    ((uint32_t)0x80000000)      /*< OTP last command execution error */

/*< Direct control register */
#define OTP_DIR_CTRL_WEB                    ((uint32_t)0x00000001)      /*< Controls the corresponding block signal */
#define OTP_DIR_CTRL_RSTB                   ((uint32_t)0x00000002)      /*< Controls the corresponding block signal */
#define OTP_DIR_CTRL_READEN                 ((uint32_t)0x00000004)      /*< Controls the corresponding block signal */
#define OTP_DIR_CTRL_PGMEN                  ((uint32_t)0x00000008)      /*< Controls the corresponding block signal */
#define OTP_DIR_CTRL_DLE                    ((uint32_t)0x00000010)      /*< Controls the corresponding block signal */
#define OTP_DIR_CTRL_DIN_0                  ((uint32_t)0x00000020)      /*< Controls the corresponding block signal */
#define OTP_DIR_CTRL_DIN_1                  ((uint32_t)0x00000040)      /*< Controls the corresponding block signal */
#define OTP_DIR_CTRL_DIN_2                  ((uint32_t)0x00000080)      /*< Controls the corresponding block signal */
#define OTP_DIR_CTRL_DIN_3                  ((uint32_t)0x00000100)      /*< Controls the corresponding block signal */
#define OTP_DIR_CTRL_CPUMPEN                ((uint32_t)0x00000200)      /*< Controls the corresponding block signal */
#define OTP_DIR_CTRL_CLE                    ((uint32_t)0x00000400)      /*< Controls the corresponding block signal */
#define OTP_DIR_CTRL_CEB                    ((uint32_t)0x00000800)      /*< Controls the corresponding block signal */
#define OTP_DIR_CTRL_A_MASK                 ((uint32_t)0x1FFFF000)      /*< Controls the corresponding block signal */
