#ifndef __UART_H__
#define __UART_H__

#define UART_CLK                        8e6

//#define BAUD_RATE                       230400
//#define BAUD_RATE                       38400
#define BAUD_RATE                       9600
//#define BAUD_RATE                       115200
#define BR_DEV                          30              /* Baudrate Deviation [%] */
#define WO_ERR_CNT                      5

#define CMD_SYNC                        '\0'
#define CMD_CR                          '\r'
#define CMD_LOAD                        'L'
#define CMD_VFY                         'Y'
#define CMD_RUN                         'R'
#define CMD_BAUD                        'B'

#define REPLY_ERR                       'E'
#define ERR_CHN                         'i'
#define ERR_CMD                         'c'
#define ERR_BAUD                        'b'
#define ERR_ADDR                        'a'
#define ERR_SIZE                        'z'
#define ERR_SPTR                        's'

#define REPLY_OK                        'K'



#define BAUD_RATE_MIN                   (BAUD_RATE * (1.0 - BR_DEV/100.0))
#define BAUD_RATE_MAX                   (BAUD_RATE * (1.0 + BR_DEV/100.0))

#define GetDiv(clk, baud)               ((float)clk/(16*baud))
#define GetIntDiv(baud)                 ((u32)(64*GetDiv(UART_CLK, baud) + 0.5))

#define DIV_MIN                         GetIntDiv(BAUD_RATE_MAX)
#define DIV_MAX                         GetIntDiv(BAUD_RATE_MIN)
#define DIV_RANGE                       (DIV_MAX - DIV_MIN)
#define DIV_DLT                         (DIV_RANGE/BR_DEV/4 ? DIV_RANGE/BR_DEV/4 : 1)

#define UART_MODE_TEST                  (UART_CR_UARTEN | UART_CR_TXE | UART_CR_RXE)
#define UART_MODE_WORK                  (UART_CR_UARTEN | UART_CR_TXE | UART_CR_RXE)


typedef struct
{
  u32                   ClkPer;
  PORT_TypeDef *               Port;
} uconf;


UART_TypeDef * UartModeInit();
void UartSetBaud(UART_TypeDef * uart, u32 divider);
void UartSendByte(UART_TypeDef * uart, u32 ch);
u32  UartReceiveByte(UART_TypeDef * uart);
u32  UartSyncErr(UART_TypeDef * uart);
u32  UartReceiveParam(UART_TypeDef * uart);

#endif /* __UART_H__ */

